# frozen_string_literal: true

require 'litbuild/blueprint'

module Litbuild
  class Commands < Blueprint
    def self.directory_name
      'commands'
    end

    def accept(visitor:)
      super
      visitor.visit_commands(commands: self)
    end

    def files
      return @files if @files

      @files = {}
      (directives['file'] || []).each do |a_file|
        add_file_content(a_file)
      end
      @files
    end

    protected

    def add_file_content(directive)
      unless directive['name'] && directive['content']
        raise(InvalidDirective, 'file directive missing name or content')
      end

      content = @files[directive['name'].first] ||= StringIO.new
      content.puts(directive['content'].first)
    end
  end
end
