# frozen_string_literal: true

module Litbuild
  # Superclass for all Litbuild errors
  class Error < RuntimeError; end

  # One or more required configuration parameters has not been provided
  class ParameterMissing < Error; end

  # A child class of Blueprint is expected to have defined a method, but
  # has not done so.
  class SubclassResponsibility < Error; end

  # A blueprint was asked to build a phase that has not been defined.
  class InvalidParameter < Error; end

  # A blueprint directive is missing the expected structure
  class InvalidDirective < Error; end

  # The source tarfile and/or patches for a package were not found in
  # the expected location.
  class MissingSource < Error; end

  # One of the blueprints referenced in the build set is not defined.
  class UnknownBlueprint < Error; end

  # A blueprint directive block could not be parsed
  class ParseError < Error; end

  # More than one blueprint exists with some name.
  class DuplicateBlueprint < Error; end

  # A blueprints directive specifies a blueprint that has already been
  # included elsewhere.
  class UnrenderedComponent < Error; end

  # A command run under `sudo` without specified path cannot be found in
  # any of the standard directories.
  class SudoProgramNotFound < Error; end
end
