# frozen_string_literal: true

require 'litbuild/errors'
require 'litbuild/visitor'

module Litbuild
  ##
  # This is a base class for Visitors that can be sent to multiple Parts
  # and/or Appendices. It is appropriate for Visitors like
  # AsciiDocVisitors.
  class MultiPartVisitor < Visitor
    def initialize(directory:)
      super
      @other_parts = []
      @appendices = []
    end

    def visit_part(part)
      @other_parts << part.name
      part.accept(visitor: self)
    end

    # We need to call some methods on the appendix blueprint, so we
    # store the entire appendix rather than just the name.
    def visit_appendix(appendix)
      @appendices << appendix
      appendix.accept(visitor: self)
    end

    protected

    attr_reader :other_parts
    attr_reader :appendices
  end
end
