# frozen_string_literal: true

module Litbuild
  # Service definition directories are a bit complicated. This is just
  # a helper class that knows how to deal with them.
  class ServiceDir
    def initialize(svcdef)
      @svcdef = svcdef
    end

    def name
      @svcdef['name'].first
    end

    def bundle
      @svcdef['bundle']&.first
    end

    def type
      return @svcdef['type'].first if @svcdef.key?('type')
      return 'longrun' if @svcdef.key?('run')
      return 'oneshot' if @svcdef.key?('up')

      raise(InvalidDirective, "servicedir #{name} must specify type")
    end

    def oneline_files
      file_contents = { 'type' => type }
      %w[down-signal notification-fd].each do |fn|
        file_contents[fn] = @svcdef[fn].first if @svcdef.key?(fn)
      end
      file_contents
    end

    def dependencies
      @svcdef['dependencies'] || []
    end

    def multiline_files
      file_contents = {}
      %w[up down run].each do |fn|
        next unless @svcdef.key?(fn)

        file_contents[fn] = @svcdef[fn]
      end
      file_contents
    end

    def env
      return [] unless @svcdef.key?('env')

      flattened = {}
      @svcdef['env'].first.each do |variable, value|
        flattened[variable] = value.first
      end
      flattened
    end
  end
end
