# frozen_string_literal: false

require 'litbuild/visitor'

module Litbuild
  # This is a simple Visitor that just accumulates the best download URL
  # for a set of Package blueprints.
  class UrlVisitor < Visitor
    def initialize
      super
      @urls = []
    end

    def visit_package(package:)
      @urls << download_url(package)
    end

    def download_url(pkg)
      url = pkg.directives['download-url'] ||
            pkg.directives['project-url'] ||
            pkg.directives['scm-url']
      url ? url.first : "#{name}: no download URL known"
    end

    def urls
      @urls.compact.flatten.sort.uniq
    end
  end
end
