# frozen_string_literal: false

module Litbuild
  ##
  # This is the base class for Litubild Visitors; it defines a
  # no-operation Visitor. Each Visitor subclass encapsulates one of the
  # operations that can be performed on a Blueprint along with its
  # dependencies and components (and along with the dependencies and
  # components of those Blueprints and so on).
  class Visitor
    # The main Visitor classes (bash script, asciidoc) write files to
    # specific directories, and need to be able to switch to
    # subdirectories tmeporarily; so Litbuild::Visitor has some
    # functionality to support that.
    #
    # The default '/' value is just to avoid nil checking for Visitors
    # that don't need this feature.
    def initialize(directory: '/')
      @dir_stack = [directory]
    end

    def in_subdirectory(subdir)
      @dir_stack.push(File.join(cwd, subdir))
      yield
      @dir_stack.pop
    end

    def visit_commands(commands:); end

    def visit_narrative(narrative:); end

    def visit_package(package:); end

    def visit_section(section:); end

    protected

    def cwd
      @dir_stack.last
    end
  end
end
